import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.util.HashMap;

public class Drumkit extends Actor
{

    private static final int NUMBER_FIRST_CRASH = 1;
    private static final String[] firstcrashSound =
        { "firstcrash" };
    private static final String[] firstcrash =
        { "Q" };
        
    private static final int NUMBER_SECOND_CRASH = 1;
    private static final String[] secondcrashSound =
        { "secondcrash" };
    private static final String[] secondcrash =
        { "W" };
        
    private static final int NUMBER_FIRST_RIDE = 1;
    private static final String[] firstrideSound =
        { "firstride" };
    private static final String[] firstride =
        { "U" };
        
    private static final int NUMBER_SECOND_RIDE = 1;
    private static final String[] secondrideSound =
        { "secondride" };
    private static final String[] secondride =
        { "Y" };

    private static final int NUMBER_SNARE = 2;
    private static final String[] snareSound =
        { "snare","snare" };
    private static final String[] snare =
        { "S","D" };
        
    private static final int NUMBER_FIRST_BASS = 1;
    private static final String[] firstbassSound =
        { "bass" };
    private static final String[] firstbass =
        { "Z" };
        
    private static final int NUMBER_SECOND_BASS = 1;
    private static final String[] secondbassSound =
        { "bass" };
    private static final String[] secondbass =
        { "x" };
    
    private static final int NUMBER_OPENED_HIHAT = 1;
    private static final String[] openedhihatSound =
        { "openedhihat" };
    private static final String[] openedhihat =
        { "T" };
        
    private static final int NUMBER_CLOSED_HIHAT = 2;
    private static final String[] closedhihatSound =
        { "closedhihat","closedhihat" };
    private static final String[] closedhihat =
        { "E","R" };    
        
    private static final int NUMBER_FIRST_TOM = 2;
    private static final String[] firsttomSound =
        { "firsttom","firsttom" };
    private static final String[] firsttom =
        { "F","G" };        
        
    private static final int NUMBER_SECOND_TOM = 2;
    private static final String[] secondtomSound =
        { "secondtom","secondtom" };
    private static final String[] secondtom =
        { "H","J" };    
        
    private static final int NUMBER_THIRD_TOM = 2;
    private static final String[] thirdtomSound =
        { "thirdtom","thirdtom" };
    private static final String[] thirdtom =
        { "K","L" };    
        
    private static final int NUMBER_FLOOR_TOM = 2;
    private static final String[] floortomSound =
        { "floortom","floortom" };
    private static final String[] floortom =
        { ";","'" };    
        
    public Drumkit()
    {
        GreenfootImage image = new GreenfootImage(600, 600);
        image.drawString("Click 'Run', then use your keyboard to play", 0, 0);
        setImage(image); 
    }
    
    public void addedToWorld(World world)
    {
        makeKeys();
    }

    public void act()
    {
    }

    /**
     * Create the drum components and place them in the world.
     */
    private void makeKeys() 
    {
        
        // first crash
        for(int i = 0; i < NUMBER_FIRST_CRASH; i++) {
            DrumComponent key = new FirstCrash(firstcrash[i], firstcrashSound[i]+".wav");
            getWorld().addObject(key, 88, 105);
        }
        
        // second crash
        for(int i = 0; i < NUMBER_SECOND_CRASH; i++) {
            DrumComponent key = new SecondCrash(secondcrash[i], secondcrashSound[i]+".wav");
            getWorld().addObject(key, 200, 105);
        }
        
        // first ride
        for(int i = 0; i < NUMBER_FIRST_RIDE; i++) {
            DrumComponent key = new FirstRide(firstride[i], firstrideSound[i]+".wav");
            getWorld().addObject(key, 512, 105);
        }
        
        // second ride
        for(int i = 0; i < NUMBER_SECOND_RIDE; i++) {
            DrumComponent key = new SecondRide(secondride[i], secondrideSound[i]+".wav");
            getWorld().addObject(key, 400, 105);
        }
        
        
        // snare
        for(int i = 0; i < NUMBER_SNARE; i++) {
            DrumComponent key = new Snare(snare[i], snareSound[i]+".wav");
            getWorld().addObject(key, 179, 382);
        }

        
        // first bass
        for(int i = 0; i < NUMBER_FIRST_BASS; i++) {
            DrumComponent key = new FirstBass(firstbass[i], firstbassSound[i]+".wav");
            getWorld().addObject(key, 263, 507);
            }
            
        // second bass
        for(int i = 0; i < NUMBER_SECOND_BASS; i++) {
            DrumComponent key = new SecondBass(secondbass[i], secondbassSound[i]+".wav");
            getWorld().addObject(key, 338, 507);
            }
            
            
        // opened hihat
        for(int i = 0; i < NUMBER_OPENED_HIHAT; i++) {
            DrumComponent key = new OpenHiHat(openedhihat[i], openedhihatSound[i]+".wav");
            getWorld().addObject(key, 71, 215);
            }
            
        // closed hihat
        for(int i = 0; i < NUMBER_CLOSED_HIHAT; i++) {
            DrumComponent key = new CloseHiHat(closedhihat[i], closedhihatSound[i]+".wav");
            getWorld().addObject(key, 71, 248);
            }
            
            
        // first tom
        for(int i = 0; i < NUMBER_FIRST_TOM; i++) {
            DrumComponent key = new FirstTom(firsttom[i], firsttomSound[i]+".wav");
            getWorld().addObject(key, 193, 246);
            }
            
        // second tom
        for(int i = 0; i < NUMBER_SECOND_TOM; i++) {
            DrumComponent key = new SecondTom(secondtom[i], secondtomSound[i]+".wav");
            getWorld().addObject(key, 298, 246);
            }
            
        // third tom
        for(int i = 0; i < NUMBER_THIRD_TOM; i++) {
            DrumComponent key = new ThirdTom(thirdtom[i], thirdtomSound[i]+".wav");
            getWorld().addObject(key, 404, 246);
            }
            
        // floor tom
        for(int i = 0; i < NUMBER_FLOOR_TOM; i++) {
            DrumComponent key = new FloorTom(floortom[i], floortomSound[i]+".wav");
            getWorld().addObject(key, 421, 383);
            }
            
            
        }
    }
